from analysis_basic import AnalysisBasic

class Loto7Analysis(AnalysisBasic):
    def __init__(self, loto7_data):
        super().__init__(loto7_data, 7)

    def __str__(self):
        return 'ロト7の当選番号を予想します。'


if __name__ == '__main__':
    pass



import sys
from all_loto import AllLoto

def main():
    all_loto = AllLoto()

    if len(sys.argv) != 2:
        print("""引数の数が違います。
loto7 抽選回(1〜)
""")
        sys.exit()

    round = int(sys.argv[1])
    if round <= 0 or round > len(all_loto.loto7):
        print("抽選回が最大値を超えています。")
        print("抽選回≦{}".format(len(all_loto.loto7)))
        sys.exit()

    data = all_loto.data(7, int(sys.argv[1]))
    print(data.nums, data.bonus)

if __name__ == '__main__':
    main()



import sys
import numpy as np
from all_loto import AllLoto
from miniloto_analysis import MinilotoAnalysis
from loto6_analysis import Loto6Analysis
from loto7_analysis import Loto7Analysis
from algo.distribution import distribution
# from algo import distribution as dst

def main():
    if len(sys.argv) != 2:
        print("""引数の数が違います。
loto 種別(5,6,7) 抽選回(1〜)
""")
        sys.exit()

    div = int(sys.argv[1])
    if div < 5 or div > 7:
        print("宝くじ種別が違います。")
        print("""宝くじ種別:
5:ミニロト
6:ロト6
7:ロト7""")
        sys.exit()

    loto_class = [MinilotoAnalysis, Loto6Analysis, Loto7Analysis]

    all_loto = AllLoto()
    loto_data = [all_loto.miniloto, all_loto.loto6, all_loto.loto7]
        
    analysis = loto_class[div-5](loto_data[div-5])

    print(analysis.frequency())
    ratio = analysis.number_ratio()
    for no, i in enumerate(ratio):
        print("{number:2}:{val:5.3}".format(number=no+1, val=i*100))

    print(sum(ratio))

if __name__ == '__main__':
    main()



from analysis_basic import AnalysisBasic

class Loto6Analysis(AnalysisBasic):
    def __init__(self, loto6_data):
        super().__init__(loto6_data, 6)

    def __str__(self):
        return 'ロト6の当選番号を予想します。'


if __name__ == '__main__':
    pass




import os, csv
from loto_basic import LotoBasic

def read_miniloto():
    csv_file = os.path.dirname(os.path.abspath(__file__)) + '/data/miniloto.csv'
    miniloto_data = []
    with open(csv_file, 'rt') as fin:
        reader = csv.reader(fin)
        for num, row in enumerate(reader):
            if num == 0:
                continue
            miniloto = LotoBasic(row[0],\
                    [int(row[2]), int(row[3]), int(row[4]),\
                    int(row[5]), int(row[6])], [int(row[7])],\
                    [int(row[8]), int(row[9]), int(row[10]), int(row[11])],\
                    [int(row[12]), int(row[13]), int(row[14]), int(row[15])])
            miniloto_data.insert(0, miniloto)

    return miniloto_data

if __name__ == '__main__':
    data = read_miniloto()
    for i in data:
        print(i)



from collections import defaultdict
import numpy as np # 後で必要なのでインポートしておく

class AnalysisBasic:
    def __init__(self, loto_data, loto_div):
        """
        loto_data: ロトくじデータ
        loto_div:  ロトくじ区分(5:ミニロト,6:ロト6, 7:ロト7)
        """
        self._data = loto_data # LotoBasicオブジェクトのリスト
        self.div = loto_div

    @property
    def max_no(self):
        return [31, 43, 37][self.div - 5]

    def frequency(self):
        """抽選数字の出現頻度をリストで返す
        """
        nums_dist = defaultdict(int)
        for loto_basic in self._data:
            for col in range(self.div):
                number = int(loto_basic.nums[col])
                nums_dist[number] += 1

        dist_list = list(range(self.max_no))
        for key in nums_dist.keys():
            dist_list[key-1] = nums_dist[key]

        return dist_list

    def number_ratio(self):
        """抽選数字の出現確率を返す
        """
        nums_ratio = np.array(self.frequency(), dtype=np.float64)
        return nums_ratio / sum(nums_ratio)



import sys, os, csv
# import loto_basic
from read_miniloto import read_miniloto
from read_loto6 import read_loto6
from read_loto7 import read_loto7

class AllLoto:
    def __init__(self):
        self.miniloto = read_miniloto()
        self.loto6 = read_loto6()
        self.loto7 = read_loto7()

    def data(self, div, round):
        """
        ロトくじの当選データを返す。
        div:  宝くじ種別(数値 5:ミニロト, 6:ロト6, 7:ロト7)
        round: 抽選回(1〜)
        """
        if div== 5:
            return self.miniloto[round - 1]
        elif div == 6:
            return self.loto6[round - 1]
        elif div == 7:
            return self.loto7[round - 1]
        else:
            raise '宝くじ種別が不正です。div={}'.format(div)

if __name__ == '__main__':
    all_loto = AllLoto()
    loto = all_loto.data(7, 208)
    print(loto.nums)     # 当選番号のリスト
    print(loto.bonus)    # ボーナス数字のリスト
    print(loto.priznum)  # 当選者数のリスト
    print(loto.amounts)  # 当選金額のリスト
    print(loto.c_over)   # キャリーオーバー金額



from analysis_basic import AnalysisBasic

class MinilotoAnalysis(AnalysisBasic):
    def __init__(self, miniloto_data):
        super().__init__(miniloto_data, 5)

    def __str__(self):
        return 'ミニロトの当選番号を予想します。'


if __name__ == '__main__':
    pass



class LotoBasic:
    def __init__(self, round, numbers, bonus_numbers, prize_nums, amount_nums, carry_over=0):
        """
        round: 回
        numbers: 当選番号のリスト
        bonus_numbers: ボーナス数字のリスト
        prize_nums: 当選者数のリスト
        amount_nums: 当選金額のリスト
        carry_over: キャリーオーバーの金額
        """

        self._round = round
        self._numbers = numbers
        self._bn = bonus_numbers
        self._pn = prize_nums
        self._an = amount_nums
        self._co = carry_over

    @property
    def nums(self):
        return self._numbers

    @property
    def bonus(self):
        return self._bn

    @property
    def priznum(self):
        return self._pn

    @property
    def amounts(self):
        return self._an

    @property
    def c_over(self):
        return self._co

    def __str__(self):
        bn_str = '[' + ','.join([str(i) for i in self._bn]) + ']'

        return "({round}) {numbers} {bn} PN[{pn}] AN[{an}] CO({co})".format(round=self._round,\
                numbers=','.join([str(i) for i in self._numbers]),\
                bn=bn_str, pn=','.join([str(i) for i in self._pn]),
                an=','.join([str(i) for i in self._an]), co=self._co)

# 以下はテストコードなので削除してもかまわない
if __name__ == '__main__':
    # miniloto = LotoBasic(939, [8, 12, 20, 23, 28], [16], [10, 20, 30, 40, 50], [100, 200, 300, 400, 500])
    # loto6 = LotoBasic(1207, [6, 16, 17, 20, 22, 43], [34], [10, 20, 30, 40, 50, 60], [100, 200, 300, 400, 500, 600], 123456)
    loto7 = LotoBasic(229, [2, 3, 9, 30, 33, 36, 37], [1, 32], [10, 20, 30, 40, 50, 60, 70], [100, 200, 300, 400, 500, 600, 700], 7777777)
    # print(miniloto)
    # print(loto6)
    print(loto7)



import numpy as np

def distribution(analysis):
    # 抽選数字の分布を表示する
    num_list = analysis.distribution()

    for no, i in enumerate(num_list):
        print('{round}: {num}'.format(round=no, num=i))



from setuptools import setup, find_packages
import sys, os

version = '0.0.6'

setup(name='lotonumber',
      version=version,
      description="show a right number of loto.",
      long_description="""\
show a correct number of loto.""",
      classifiers=[], # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      keywords='loto number',
      author='solima',
      author_email='',
      url='',
      license='GPL',
      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          # -*- Extra requirements: -*-
          'numpy',
      ],
      entry_points="""
      # -*- Entry points: -*-
      [console_scripts]
      loto = lotonumber.loto:main
      miniloto = lotonumber.miniloto:main
      loto6 = lotonumber.loto6:main
      loto7 = lotonumber.loto7:main
      """,
      )



import os, csv
from loto_basic import LotoBasic

def read_loto6():
    csv_file = os.path.dirname(os.path.abspath(__file__)) + '/data/loto6.csv'
    loto6_data = []
    with open(csv_file, 'rt') as fin:
        reader = csv.reader(fin)
        for num, row in enumerate(reader):
            if num == 0:
                continue
            loto6 = LotoBasic(row[0],\
                    [int(row[2]), int(row[3]), int(row[4]),\
                    int(row[5]), int(row[6]), int(row[7])],\
                    [int(row[8])],\
                    [int(row[9]), int(row[10]), int(row[11]), int(row[12]), int(row[13])],\
                    [int(row[14]), int(row[15]), int(row[16]), int(row[17]), int(row[18])], int(row[19]) )
            loto6_data.insert(0, loto6)

    return loto6_data

if __name__ == '__main__':
    data = read_loto6()
    for i in data:
        print(i)
